Package: countfitteR
Type: Package
Title: Comprehensive Automatized Evaluation of Distribution Models for
        Count Data
Version: 1.5
Authors@R: c(person("Jaroslaw", "Chilimoniuk", 
           email = "jaroslaw.chilimoniuk@gmail.com", 
           comment = c(ORCID = "0000-0001-5467-018X"),
           role = c("cre", "ctb")),
            person("Alicja", "Gosiewska", 
           email = "alicjagosiewska@gmail.com", 
           comment = c(ORCID = "0000-0001-6563-5742"),
           role = c("ctb")),
            person("Jadwiga", "Słowik", 
           email = "slowikj@student.mini.pw.edu.pl", 
           comment = c(ORCID = "0000-0003-3466-8933"),
           role = c("ctb")),
            person("Michal", "Burdukiewicz", 
           email = "michalburdukiewicz@gmail.com", 
           comment = c(ORCID = "0000-0001-8926-582X"),
           role = c("aut")),
            person("Stefan", "Roediger", 
           email = "stefan.roedigier@b-tu.de", 
           comment = c(ORCID = "0000-0002-1441-6512"),
           role = ("ctb"))
           )
Maintainer: Jaroslaw Chilimoniuk <jaroslaw.chilimoniuk@gmail.com>
Description: A large number of measurements generate count data. This is a statistical data type 
    that only assumes non-negative integer values and is generated by counting. Typically, counting 
    data can be found in biomedical applications, such as the analysis of DNA double-strand breaks. 
    The number of DNA double-strand breaks can be counted in individual cells using various 
    bioanalytical methods. For diagnostic applications, it is relevant to record the distribution of 
    the number data in order to determine their biomedical significance (Roediger, S. et al., 2018. 
    Journal of Laboratory and Precision Medicine. <doi:10.21037/jlpm.2018.04.10>). The software 
    offers functions for a comprehensive automated evaluation of distribution models of count 
    data. In addition to programmatic interaction, a graphical user interface (web server) 
    is included, which enables fast and interactive data-scientific analyses. The user is supported 
    in selecting the most suitable counting distribution for his own data set.
License: GPL-3
Encoding: UTF-8
LazyData: true
VignetteBuilder: knitr
Suggests: dplyr, DT, gridExtra, knitr, pander, reshape2, rmarkdown,
        shinythemes, shinycssloaders, shinyWidgets, spelling, testthat
Date: 2025-07-01
URL: https://github.com/BioGenies/countfitteR
BugReports: https://github.com/BioGenies/countfitteR/issues
RoxygenNote: 7.3.2
Imports: ggplot2, MASS, shiny, stats, pscl, tools, utils
Language: en-US
NeedsCompilation: no
Packaged: 2025-07-01 09:59:18 UTC; jarek
Author: Jaroslaw Chilimoniuk [cre, ctb] (ORCID:
    <https://orcid.org/0000-0001-5467-018X>),
  Alicja Gosiewska [ctb] (ORCID: <https://orcid.org/0000-0001-6563-5742>),
  Jadwiga Słowik [ctb] (ORCID: <https://orcid.org/0000-0003-3466-8933>),
  Michal Burdukiewicz [aut] (ORCID:
    <https://orcid.org/0000-0001-8926-582X>),
  Stefan Roediger [ctb] (ORCID: <https://orcid.org/0000-0002-1441-6512>)
Repository: CRAN
Date/Publication: 2025-07-01 10:30:11 UTC
Built: R 4.6.0; ; 2026-04-26 12:27:21 UTC; unix
