# Generated by roxygen2: do not edit by hand

export(compare_fit)
export(countfitteR_gui)
export(dZINB)
export(dZIP)
export(decide)
export(fit_counts)
export(plot_fitcmp)
export(process_counts)
export(rZINB)
export(rZIP)
export(select_model)
export(summary_fitlist)
export(validate_counts)
importFrom(MASS,glm.nb)
importFrom(ggplot2,aes)
importFrom(ggplot2,facet_grid)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,scale_color_discrete)
importFrom(pscl,zeroinfl)
importFrom(shiny,runApp)
importFrom(stats,.getXlevels)
importFrom(stats,AIC)
importFrom(stats,binomial)
importFrom(stats,confint.default)
importFrom(stats,delete.response)
importFrom(stats,dnbinom)
importFrom(stats,dpois)
importFrom(stats,filter)
importFrom(stats,glm)
importFrom(stats,glm.fit)
importFrom(stats,lag)
importFrom(stats,logLik)
importFrom(stats,mad)
importFrom(stats,make.link)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,model.weights)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,optim)
importFrom(stats,pnorm)
importFrom(stats,poisson)
importFrom(stats,predict)
importFrom(stats,printCoefmat)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(tools,md5sum)
importFrom(tools,package_dependencies)
importFrom(utils,available.packages)
importFrom(utils,tail)
