## About  

The countfitteR web server relies on function from the [countfitteR](https://github.com/BioGenies/countfitteR) package for **R**.

### Authors

[Michał Burdukiewicz](https://www.researchgate.net/profile/Michal_Burdukiewicz)

[Stefan Rödiger](https://www.researchgate.net/profile/Stefan_Roediger)

[Jarosław Chilimoniuk](https://www.researchgate.net/profile/Jaroslaw_Chilimoniuk)

[Alicja Gosiewska](https://www.researchgate.net/profile/Alicja_Gosiewska)

[Jadwiga Słowik](https://github.com/slowikj)
  
  
  
### How to cite

Chilimoniuk J, Gosiewska A, Słowik J, Roediger S and Burdukiewicz M (2020). countfitteR: comprehensive automatized evaluation of distribution models for count data. R package version 1.4. https://cran.r-project.org/package=countfitteR.


```tex
@Manual{,
  author = {Jaroslaw Chilimoniuk and Alicja Gosiewska and Jadwiga Słowik and Stefan Roediger and Michal Burdukiewicz},
  title = {countfitteR: comprehensive automatized evaluation of distribution models for count data},
  year = {2020},
  note = {R package version 1.4},
  url = {https://CRAN.R-project.org/package=countfitteR},
}
```
