## Compare distributions

Compare an empirical distribution of counts with a distribution defined by the model fitted to counts. Points indicate the real number of counts, while bars the number of counts estimated by a distribution.
