## Settings

If the "Separate experiements" checkbox is marked, the model assumes that all counts may come from different distributions. See the manual for more information. The "Confidence level" parameter specifies the confidence level used in the workflow. All settings will be visible in the report, but not on tables and charts downloaded separately.
