## Data upload

Use this panel to load your count data. 
The example data set is already preloaded.

### Data structure

Each column should represent a separate series of counts. If the first row contains headers, mark the Header checkbox. The type of your .csv file might be further specified.
